@@ -1,5 +1,5 @@
 package File::Dir::Dumper::App;
-$File::Dir::Dumper::App::VERSION = '0.6.5';
+$File::Dir::Dumper::App::VERSION = '0.6.6';
 use warnings;
 use strict;
 
@@ -50,6 +50,10 @@ sub _init
     pod2usage( -exitstatus => 0, -verbose => 2 ) if $man;
 
     my $dir_to_dump = shift(@$argv);
+    if ( not length $dir_to_dump )
+    {
+        die "dir_to_dump must be specified!";
+    }
 
     if ( defined($output_dest) )
     {
@@ -124,7 +128,7 @@ dumping.
 
 =head1 VERSION
 
-version 0.6.5
+version 0.6.6
 
 =head1 SYNOPSIS
 
