@@ -1,5 +1,5 @@
 package File::Dir::Dumper::Scanner;
-$File::Dir::Dumper::Scanner::VERSION = '0.6.5';
+$File::Dir::Dumper::Scanner::VERSION = '0.6.6';
 use warnings;
 use strict;
 use autodie;
@@ -130,19 +130,21 @@ sub _up_to_level
     my $self         = shift;
     my $target_level = shift;
 
-    my $last_result = $self->_last_result();
-
-    for my $level (
-        reverse( $target_level .. $#{ $last_result->dir_components() } ) )
+    if ( my $last_result = $self->_last_result() )
     {
-        $self->_add(
-            {
-                type  => "updir",
-                depth => $level + 1,
-            }
-        );
-    }
 
+        for my $level (
+            reverse( $target_level .. $#{ $last_result->dir_components() } ) )
+        {
+            $self->_add(
+                {
+                    type  => "updir",
+                    depth => $level + 1,
+                }
+            );
+        }
+
+    }
     return;
 }
 
@@ -152,7 +154,7 @@ sub _find_new_common_depth
 
     my $result      = $self->_result();
     my $last_result = $self->_last_result();
-
+    return 0 if ( ( !$last_result ) or ( !$result ) );
     my $depth = 0;
 
     my $upper_limit = min(
@@ -306,10 +308,19 @@ sub _populate_queue
     if ( !$self->_last_result() )
     {
         $self->_add( { type => "dir", depth => 0 } );
+        if ( !$self->_result() )
+        {
+            $self->_add( { type => "footer" } );
+
+            $self->_reached_end(1);
+        }
     }
     elsif ( !$self->_result() )
     {
-        $self->_up_to_level(-1);
+        if ( $self->_last_result() )
+        {
+            $self->_up_to_level(-1);
+        }
 
         $self->_add( { type => "footer" } );
 
@@ -341,11 +352,11 @@ hash-refs
 
 =head1 VERSION
 
-version 0.6.5
+version 0.6.6
 
 =head1 SYNOPSIS
 
-    use File::Dir::Dumper::Scanner;
+    use File::Dir::Dumper::Scanner ();
 
     my $scanner = File::Dir::Dumper::Scanner->new(
         {
